@@ -4,19 +4,11 @@ use super::{Inner, Limb};
 use crate::Encoding;
 
 impl Encoding for Limb {
-    // 32-bit
-    #[cfg(target_pointer_width = "32")]
-    const BIT_SIZE: usize = 32;
-    #[cfg(target_pointer_width = "32")]
-    const BYTE_SIZE: usize = 4;
+    const BIT_SIZE: usize = super::BIT_SIZE;
+    const BYTE_SIZE: usize = super::BYTE_SIZE;
+
     #[cfg(target_pointer_width = "32")]
     type Repr = [u8; 4];
-
-    // 64-bit
-    #[cfg(target_pointer_width = "64")]
-    const BIT_SIZE: usize = 64;
-    #[cfg(target_pointer_width = "64")]
-    const BYTE_SIZE: usize = 8;
     #[cfg(target_pointer_width = "64")]
     type Repr = [u8; 8];
 
