@@ -15,9 +15,12 @@ mod sub;
 #[cfg(feature = "generic-array")]
 mod array;
 
+#[cfg(feature = "rand")]
+mod rand;
+
 use crate::{Concat, Encoding, Limb, Split};
 use core::fmt;
-use subtle::{Choice, ConditionallySelectable, ConstantTimeEq};
+use subtle::{Choice, ConditionallySelectable};
 
 #[cfg(feature = "zeroize")]
 use zeroize::Zeroize;
@@ -44,6 +47,11 @@ impl<const LIMBS: usize> UInt<LIMBS> {
         limbs: [Limb::MAX; LIMBS],
     };
 
+    /// Const-friendly [`UInt`] constructor.
+    pub const fn new(limbs: [Limb; LIMBS]) -> Self {
+        Self { limbs }
+    }
+
     /// Borrow the limbs of this [`UInt`].
     // TODO(tarcieri): eventually phase this out?
     pub const fn limbs(&self) -> &[Limb; LIMBS] {
@@ -55,15 +63,6 @@ impl<const LIMBS: usize> UInt<LIMBS> {
     pub const fn into_limbs(self) -> [Limb; LIMBS] {
         self.limbs
     }
-
-    /// Determine if this [`UInt`] is equal to zero.
-    ///
-    /// # Returns
-    ///
-    /// If zero, return `Choice(1)`.  Otherwise, return `Choice(0)`.
-    pub fn is_zero(&self) -> Choice {
-        self.ct_eq(&Self::ZERO)
-    }
 }
 
 // TODO(tarcieri): eventually phase this out?
@@ -196,13 +195,6 @@ impl_split! {
 mod tests {
     use crate::{Concat, Split, U128, U64};
 
-    // 2-limb example that's twice as wide as the native word size
-    #[cfg(target_pointer_width = "32")]
-    use crate::U64 as UIntEx;
-
-    #[cfg(target_pointer_width = "64")]
-    use crate::U128 as UIntEx;
-
     #[test]
     #[cfg(feature = "alloc")]
     fn display() {
@@ -213,12 +205,6 @@ mod tests {
         assert_eq!(hex, n.to_string());
     }
 
-    #[test]
-    fn is_zero() {
-        assert!(bool::from(UIntEx::ZERO.is_zero()));
-        assert!(!bool::from(UIntEx::ONE.is_zero()));
-    }
-
     #[test]
     fn concat() {
         let hi = U64::from_u64(0x0011223344556677);
